aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRob Savoye <rob.savoye@linaro.org>2014-11-18 08:14:04 +0000
committerRob Savoye <rob.savoye@linaro.org>2014-11-18 08:14:04 +0000
commitb7a5c4b06c4f3f7fd2a3a4164b0cc7fb45f8487a (patch)
treed6c546069be069fff739cebbfb80104ba9221fa1
parente20349f81b57fef81c039c1062bb56ee04542304 (diff)
parent718adcf2379e56e9cc37ca08a7d0853fb6e81d1e (diff)
Merge branch 'abe'
Rename everything.
-rw-r--r--README36
-rwxr-xr-xabe.sh (renamed from cbuild2.sh)38
-rw-r--r--config/boards/README2
-rw-r--r--config/boards/tcwglava.exp2
-rw-r--r--config/boards/tcwgrob/arm-odroidU2.exp2
-rw-r--r--config/sources.conf2
-rwxr-xr-xconfigure30
-rw-r--r--configure.ac16
-rwxr-xr-xjenkins.sh38
-rw-r--r--lib/checkout.sh4
-rw-r--r--lib/common.sh2
-rw-r--r--lib/diff.sh8
-rw-r--r--lib/gerrit.sh6
-rw-r--r--lib/git-parser.sh2
-rw-r--r--lib/globals.sh4
-rwxr-xr-xlib/make.sh2
-rw-r--r--lib/merge.sh2
-rw-r--r--lib/package.sh12
-rwxr-xr-xlib/release.sh4
-rw-r--r--lib/stamp.sh2
-rwxr-xr-xrunbenchmark.sh4
-rwxr-xr-xscripts/Backport.job8
-rwxr-xr-xscripts/BuildFarm.job8
-rwxr-xr-xscripts/MakeRelease.job18
-rwxr-xr-xtcwgweb.sh12
-rwxr-xr-xtest-backport.sh16
-rwxr-xr-xtest.sh32
-rwxr-xr-xtestsuite/gerrit-tests.sh4
-rw-r--r--testsuite/git-parser-tests.sh2
-rw-r--r--testsuite/normalize-tests.sh2
-rw-r--r--testsuite/srcdir-tests.sh48
-rwxr-xr-xtestsuite/test.sh32
-rw-r--r--testsuite/test_sources.conf2
-rwxr-xr-xvalidate.sh26
34 files changed, 214 insertions, 214 deletions
diff --git a/README b/README
index 8f03aaa..3be9a50 100644
--- a/README
+++ b/README
@@ -1,19 +1,19 @@
README
-Cbuildv2 is a bourne shell rewrite of the existing cbuild system as
+Abe is a bourne shell rewrite of the existing Cbuildv1 system as
used by Linaro. While being oriented to the Linaro way of doing
-things, Cbuildv2 should be usable by others by just reconfiguring.
+things, Abe should be usable by others by just reconfiguring.
-Configuring Cbuildv2:
+Configuring Abe:
---------------------
- While it is possible to run Cbuildv2 from it's source tree, this
+ While it is possible to run Abe from it's source tree, this
isn't recommended. The best practice is to create a new build
-directory, and configure Cbuildv2 in that directory. That makes it
+directory, and configure Abe in that directory. That makes it
easy to change branches, or even delete subdirectories. There
are defaults for all paths, which is to create them under the same
directory configure is run in.
- There are several directories that Cbuildv2 needs. These are the
+ There are several directories that Abe needs. These are the
following:
* local snapshots - This is where all the downloaded sources get
@@ -23,7 +23,7 @@ following:
full hostname of the build machine. Under this a directory is
created for the target architecture.
* remote snapshots - This is where remote tarballs are stored. This
- currently defaults to cbuild.validation.linaro.org, which is
+ currently defaults to abe.validation.linaro.org, which is
accessible via HTTP to the general public.
If configure is executed without any parameters. the defaults are
@@ -33,7 +33,7 @@ time. For example:
$CBUILD-PATH/configure
--with-local-snapshots=$CBUILD_PATH/snapshots
--with-local-builds=$CBUILD-PATH/destdir
---with-remote-snapshots=cbuild@toolchain64.lab:/home/cbuild/var/snapshots/
+--with-remote-snapshots=abe@toolchain64.lab:/home/abe/var/snapshots/
This changes the 3 primary paths, including changing the remote host
to use rsync or ssh to download tarballs instead of HTTP. You can
@@ -41,8 +41,8 @@ execute ./configure --help to get the full list of configure time
parameters.
The configure process produces a host.conf file, with the default
-settings. This file is read by cbuildv2 at runtime, so it's possible to
-change the values and rerun cbuild2.sh to use the new values. Each
+settings. This file is read by abe at runtime, so it's possible to
+change the values and rerun abe.sh to use the new values. Each
toolchain component also has a config file. The default version is
copied at build time to the build tree. It is also possible to edit
this file, usually called something like gcc.conf, to change the
@@ -96,28 +96,28 @@ host, and contains the other packages needed to build GCC, like
gmp. Snapshots is the primary location of all source tarballs. To list
all the available snapshots, you can do this"
- "cbuild2.sh --list snapshots".
+ "abe.sh --list snapshots".
-You can also run cbuildv2 with the --interactive options, which will
+You can also run abe with the --interactive options, which will
display a subset of all the packages that matches the supplied
string. To build a specific component, use the --build option to
-cbuildv2. the --target option is also used for cross builds. For
+abe. the --target option is also used for cross builds. For
example:
-"cbuild2.sh --target arm-none-linux-gnueabihf gcc-linaro-4.8.2013.07-1"
+"abe.sh --target arm-none-linux-gnueabihf gcc-linaro-4.8.2013.07-1"
This would fetch the source tarball for this release, build anything
it needs to compile, the binutils for example, and then build these
sources. You can also specify a URL to a source repository
instead. For example:
-"cbuild2.sh --target arm-none-linux-gnueabihf git://git.linaro.org/toolchain/eglibc.git"
+"abe.sh --target arm-none-linux-gnueabihf git://git.linaro.org/toolchain/eglibc.git"
To build an entire cross toolchain, the simplest way is to let
-cbuildv2 control all the steps. Although it is also possible to do each
+abe control all the steps. Although it is also possible to do each
step separately. To build the full toolchain, do this:
-"cbuild2.sh --target arm-none-linux-gnueabihf --build all"
+"abe.sh --target arm-none-linux-gnueabihf --build all"
---------------------------------------------------------------------
Older NOTES
@@ -161,7 +161,7 @@ Features:
* Queue jobs for LAVA
* Lists possible versions and components for build
-cbuild2 command line arguments:
+abe command line arguments:
-------------------------------
* --build (architecture for the build machine, default native)
* --target (architecture for the target machine, default native)
diff --git a/cbuild2.sh b/abe.sh
index 42fd0cb..f82e7a4 100755
--- a/cbuild2.sh
+++ b/abe.sh
@@ -20,7 +20,7 @@ usage()
{
# Format this section with 75 columns.
cat << EOF
- ${cbuild2} [''| [--timeout <value>]
+ ${abe} [''| [--timeout <value>]
[[--build [<package> --stage {1|2}]|all]
|[--checkout <package>|all]]
[--ccache] [--check] [--enable {bootstrap|gerrit}]
@@ -46,7 +46,7 @@ help()
cat << EOF
NAME
- ${cbuild2} - the Linaro Toolchain Build Framework.
+ ${abe} - the Linaro Toolchain Build Framework.
SYNOPSIS
@@ -65,14 +65,14 @@ KEY
DESCRIPTION
- ${cbuild2} is a toolchain build framework. The primary purpose of
- ${cbuild2} is to unify the method used to build cross, native, and
+ ${abe} is a toolchain build framework. The primary purpose of
+ ${abe} is to unify the method used to build cross, native, and
Canadian-cross GNU toolchains.
PRECONDITIONS
Autoconf (configure) must be run in order to construct the build
- directory and host.conf file before it is valid to run ${cbuild2}.
+ directory and host.conf file before it is valid to run ${abe}.
OPTIONS
@@ -133,7 +133,7 @@ OPTIONS
This is a debugging aid for developers, as it
assumes everything built correctly...
- --dryrun Run as much of ${cbuild2} as possible without doing any
+ --dryrun Run as much of ${abe} as possible without doing any
actual configuration, building, or installing.
--dump Dump configuration file information for this build.
@@ -239,7 +239,7 @@ OPTIONS
''
Build the toolchain native to the hardware that
- ${cbuild2} is running on.
+ ${abe} is running on.
<target_triple>
@@ -253,7 +253,7 @@ OPTIONS
aarch64_be-none-linux-gnu
If <target_triple> is not the same as the hardware
- that ${cbuild2} is running on then build the
+ that ${abe} is running on then build the
toolchain as a cross toolchain.
--timeout <timeout_value>
@@ -288,19 +288,19 @@ EXAMPLES
Build a Linux cross toolchain:
- ${cbuild2} --target arm-none-linux-gnueabihf --build all
+ ${abe} --target arm-none-linux-gnueabihf --build all
Build a Linux cross toolchain with glibc as the clibrary:
- ${cbuild2} --target arm-none-linux-gnueabihf --set libc=glibc --build all
+ ${abe} --target arm-none-linux-gnueabihf --set libc=glibc --build all
Build a bare metal toolchain:
- ${cbuild2} --target aarch64-none-elf --build all
+ ${abe} --target aarch64-none-elf --build all
PRECONDITION FILES
- ~/.cbuildrc ${cbuild2} user specific configuration file
+ ~/.aberc ${abe} user specific configuration file
host.conf Generated by configure from host.conf.in.
@@ -327,7 +327,7 @@ EOF
if test $# -lt 1; then
echo "Usage:"
usage
- echo "Run \"${cbuild2} --help\" for detailed usage information."
+ echo "Run \"${abe} --help\" for detailed usage information."
exit 1
fi
@@ -345,9 +345,9 @@ else
fi
# load commonly used functions
-cbuild="`which $0`"
-topdir="${cbuild_path}"
-cbuild2="`basename $0`"
+abe="`which $0`"
+topdir="${abe_path}"
+abe="`basename $0`"
. "${topdir}/lib/common.sh" || exit 1
@@ -495,7 +495,7 @@ check_directive()
error "--${long} requires a directive. See --usage for details.' "
build_failure
elif test `echo ${directive} | egrep -c "^\-+"` -gt 0; then
- error "--${long} requires a directive. ${cbuild2} found the next -- switch. See --usage for details.' "
+ error "--${long} requires a directive. ${abe} found the next -- switch. See --usage for details.' "
else
return 0
fi
@@ -511,7 +511,7 @@ get_list()
{
echo "Get version list for $1..."
- # http://cbuild.validation.linaro.org/snapshots
+ # http://abe.validation.linaro.org/snapshots
case $1 in
testcode|t*)
testcode="`grep testcode ${local_snapshots}/testcode/md5sums | cut -d ' ' -f 3 | cut -d '/' -f 2`"
@@ -860,7 +860,7 @@ while test $# -gt 0; do
--usage)
echo "Usage:"
usage
- echo "Run \"${cbuild2} --help\" for detailed usage information."
+ echo "Run \"${abe} --help\" for detailed usage information."
exit 0
;;
*)
diff --git a/config/boards/README b/config/boards/README
index c444f5c..29759ee 100644
--- a/config/boards/README
+++ b/config/boards/README
@@ -1,6 +1,6 @@
These are the config files DejaGnu uses to access the Linaro build
farm. When the DEJAGNU environment variables is set to
-cbuild2/config/linaro.exp, then cbuild2/config/boards is prefixed to
+abe/config/linaro.exp, then abe/config/boards is prefixed to
the directory lookup paths. The top level sub directory is the shorter
nodename of the system's hostname, for example tcwgbuild01.
diff --git a/config/boards/tcwglava.exp b/config/boards/tcwglava.exp
index dd76abe..24773ac 100644
--- a/config/boards/tcwglava.exp
+++ b/config/boards/tcwglava.exp
@@ -7,4 +7,4 @@ set_board_info rcp_prog /usr/bin/scp
set_board_info gcc,timeout 100000
set_board_info hostname @LAVA_BOARD@
-set_board_info lava_json /home/maxim-kuvyrkov/src/cbuild2/config/boards/lava.json
+set_board_info lava_json /home/maxim-kuvyrkov/src/abe/config/boards/lava.json
diff --git a/config/boards/tcwgrob/arm-odroidU2.exp b/config/boards/tcwgrob/arm-odroidU2.exp
index 5b016d4..cd8f697 100644
--- a/config/boards/tcwgrob/arm-odroidU2.exp
+++ b/config/boards/tcwgrob/arm-odroidU2.exp
@@ -6,7 +6,7 @@ set_board_info hostname arm-odroidU2
set_board_info protocol fastssh
# Enable ControlMaster and ControlPath
-set_board_info rsh_opts "-o ControlMaster=auto -o ControlPath=\"/tmp/cbuild-%u@%h:[pid]\" -o ControlPersist=6h"
+set_board_info rsh_opts "-o ControlMaster=auto -o ControlPath=\"/tmp/abe-%u@%h:[pid]\" -o ControlPersist=6h"
#set_board_info username buildslave
set_board_info gcc,timeout 100000
diff --git a/config/sources.conf b/config/sources.conf
index 9d755bd..3adfaa7 100644
--- a/config/sources.conf
+++ b/config/sources.conf
@@ -16,7 +16,7 @@ gcc-embedded-4.6 svn://gcc.gnu.org/svn/gcc/branches/ARM/embedded-4_6-branch
gcc-google-4.6 svn://gcc.gnu.org/svn/gcc/branches/google/gcc-4_6
#gcc svn://gcc.gnu.org/svn/gcc/trunk
gcc.git http://git.linaro.org/git/toolchain/gcc.git
-cbuild2.git http://git.linaro.org/git/toolchain/cbuild2.git
+abe.git http://git.linaro.org/git/toolchain/abe.git
#gcc.git http://staging.git.linaro.org/git/toolchain/gcc.git
#gcc-linaro-4.7 lp:gcc-linaro/4.7
diff --git a/configure b/configure
index 38d5018..968f604 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for cbuild 2.0dev.
+# Generated by GNU Autoconf 2.69 for abe 2.0dev.
#
#
# Copyright (C) 1992-1996, 1998-2012 Free Software Foundation, Inc.
@@ -574,14 +574,14 @@ MFLAGS=
MAKEFLAGS=
# Identity of this package.
-PACKAGE_NAME='cbuild'
-PACKAGE_TARNAME='cbuild'
+PACKAGE_NAME='abe'
+PACKAGE_TARNAME='abe'
PACKAGE_VERSION='2.0dev'
-PACKAGE_STRING='cbuild 2.0dev'
+PACKAGE_STRING='abe 2.0dev'
PACKAGE_BUGREPORT=''
PACKAGE_URL=''
-ac_unique_file="cbuild2.sh"
+ac_unique_file="abe.sh"
ac_subst_vars='LTLIBOBJS
LIBOBJS
NEWWORKDIR
@@ -1255,7 +1255,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures cbuild 2.0dev to adapt to many kinds of systems.
+\`configure' configures abe 2.0dev to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1303,7 +1303,7 @@ Fine tuning of the installation directories:
--infodir=DIR info documentation [DATAROOTDIR/info]
--localedir=DIR locale-dependent data [DATAROOTDIR/locale]
--mandir=DIR man documentation [DATAROOTDIR/man]
- --docdir=DIR documentation root [DATAROOTDIR/doc/cbuild]
+ --docdir=DIR documentation root [DATAROOTDIR/doc/abe]
--htmldir=DIR html documentation [DOCDIR]
--dvidir=DIR dvi documentation [DOCDIR]
--pdfdir=DIR pdf documentation [DOCDIR]
@@ -1316,7 +1316,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of cbuild 2.0dev:";;
+ short | recursive ) echo "Configuration of abe 2.0dev:";;
esac
cat <<\_ACEOF
@@ -1429,7 +1429,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-cbuild configure 2.0dev
+abe configure 2.0dev
generated by GNU Autoconf 2.69
Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1568,7 +1568,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by cbuild $as_me 2.0dev, which was
+It was created by abe $as_me 2.0dev, which was
generated by GNU Autoconf 2.69. Invocation command line was
$ $0 $@
@@ -2966,7 +2966,7 @@ ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $
ac_compiler_gnu=$ac_cv_c_compiler_gnu
if test x"${CC}" = x -a x"${CXX}" = x; then
- as_fn_error $? "You need 'gcc' and 'g++' to fully run cbuild!" "$LINENO" 5
+ as_fn_error $? "You need 'gcc' and 'g++' to fully run abe!" "$LINENO" 5
missing="${missing} gcc"
fi
ac_aux_dir=
@@ -3158,8 +3158,8 @@ fi
if test x"${WGET}" = x; then
- { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: You need 'wget' to fully run cbuild!" >&5
-$as_echo "$as_me: WARNING: You need 'wget' to fully run cbuild!" >&2;}
+ { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: You need 'wget' to fully run abe!" >&5
+$as_echo "$as_me: WARNING: You need 'wget' to fully run abe!" >&2;}
missing="${missing} wget"
fi
@@ -4762,7 +4762,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by cbuild $as_me 2.0dev, which was
+This file was extended by abe $as_me 2.0dev, which was
generated by GNU Autoconf 2.69. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -4815,7 +4815,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-cbuild config.status 2.0dev
+abe config.status 2.0dev
configured by $0, generated by GNU Autoconf 2.69,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index 58a1544..30e3fa3 100644
--- a/configure.ac
+++ b/configure.ac
@@ -21,8 +21,8 @@ dnl build and test a GNU toolchain.
dnl
AC_PREREQ(2.59c)
-AC_INIT(cbuild, 2.0dev)
-AC_CONFIG_SRCDIR([cbuild2.sh])
+AC_INIT(abe, 2.0dev)
+AC_CONFIG_SRCDIR([abe.sh])
dnl AC_CONFIG_HEADERS([config.h])
dnl AC_CONFIG_MACRO_DIR([macros])
@@ -33,7 +33,7 @@ missing=
AC_PROG_CC
AC_PROG_CXX
if test x"${CC}" = x -a x"${CXX}" = x; then
- AC_MSG_ERROR([You need 'gcc' and 'g++' to fully run cbuild!])
+ AC_MSG_ERROR([You need 'gcc' and 'g++' to fully run abe!])
missing="${missing} gcc"
fi
AC_PROG_INSTALL
@@ -68,7 +68,7 @@ AC_SUBST(DISTRIBUTION)
AC_PATH_PROG(WGET, wget)
AC_SUBST(WGET)
if test x"${WGET}" = x; then
- AC_MSG_WARN([You need 'wget' to fully run cbuild!])
+ AC_MSG_WARN([You need 'wget' to fully run abe!])
missing="${missing} wget"
fi
@@ -205,7 +205,7 @@ BUILDDATE="`date +%Y%m%d`"
AC_SUBST(BUILDDATE)
dnl While it's a bad idea to store the database access information in an unencrypted
-dnl text file, this is useful for cbuild2 development itself. This option should never
+dnl text file, this is useful for abe development itself. This option should never
dnl be used in a production environment. The default is read-only access. You can also
dnl set DBUSER and DBPASSWD in your environment, but that's also a possible security
dnl risk.
@@ -224,7 +224,7 @@ AC_ARG_WITH(dbhost,
dbhost=${withval} ; AC_MSG_WARN([The database hostname is stored in an unencrypted text file which could be considered a security risk!]),
dbhost='localhost')
-dnl The top of the cbuild tree
+dnl The top of the abe tree
AC_ARG_WITH(toplevel,
AC_HELP_STRING([--with-toplevel], []),
ABE_TOP=${withval},
@@ -253,7 +253,7 @@ AC_SUBST(SOURCES_CONF)
ABE_PATH=$(readlink -f ${srcdir})
AC_SUBST(ABE_PATH)
-dnl The top of the cbuild tree
+dnl The top of the abe tree
AC_ARG_WITH(sysroot,
AC_HELP_STRING([--with-sysroot], []),
SYSROOTS=${withval},
@@ -394,7 +394,7 @@ AC_SUBST(ENABLE_PARALLEL)
dnl AC_ARG_WITH(snapshots,
dnl AC_HELP_STRING([--with-snapshots], []),
dnl snapshots=${withval},
-dnl snapshots='cbuild')
+dnl snapshots='abe')
dnl Since the configure script is actually checked in, a developer
dnl does not need to have the GNU Autotools installed. However,
diff --git a/lib/checkout.sh b/lib/checkout.sh
index 9c10584..907520a 100644
--- a/lib/checkout.sh
+++ b/lib/checkout.sh
@@ -24,7 +24,7 @@
# but we also want to work with the native source code control system.
usegit=no
-# This is used by cbuild2.sh --checkout all but not by --build
+# This is used by abe.sh --checkout all but not by --build
checkout_infrastructure()
{
trace "$*"
@@ -298,7 +298,7 @@ checkout()
# dryrun "(cd ${srcdir} && git checkout ${branch})"
elif test x"${supdate}" = xyes; then
# Some packages allow the build to modify the source directory and
- # that might screw up cbuild2's state so we restore a pristine branch.
+ # that might screw up abe's state so we restore a pristine branch.
notice "Updating sources for ${tool} in ${srcdir}"
dryrun "(cd ${repodir} && git stash --all)"
dryrun "(cd ${repodir} && git reset --hard)"
diff --git a/lib/common.sh b/lib/common.sh
index 5adc94e..e23f3ec 100644
--- a/lib/common.sh
+++ b/lib/common.sh
@@ -56,7 +56,7 @@ set_dbpasswd()
dbpasswd="$1"
}
-# if --dryrun is passed to cbuild2.sh, then commands are echoed instead of
+# if --dryrun is passed to abe.sh, then commands are echoed instead of
# of executed.
dryrun()
{
diff --git a/lib/diff.sh b/lib/diff.sh
index 9465736..8b1276c 100644
--- a/lib/diff.sh
+++ b/lib/diff.sh
@@ -32,8 +32,8 @@ difftwodirs ()
echo "Diffing: ${prev} against ${next}..."
local resultsdir="${local_builds}/test-results"
- local pversion="`echo ${prev} | grep -o "test-results/cbuild[0-9a-z]*" | grep -o "cbuild[0-9a-z]*"`"
- local nversion="`echo ${next} | grep -o "test-results/cbuild[0-9a-z]*" | grep -o "cbuild[0-9a-z]*"`"
+ local pversion="`echo ${prev} | grep -o "test-results/abe[0-9a-z]*" | grep -o "abe[0-9a-z]*"`"
+ local nversion="`echo ${next} | grep -o "test-results/abe[0-9a-z]*" | grep -o "abe[0-9a-z]*"`"
diffdir="${resultsdir}/diffof-${pversion}-${nversion}"
mkdir -p ${diffdir}
@@ -111,9 +111,9 @@ diffall ()
# This produces the test file, who's header needs to look like this:
#
# Difference in testsuite results between:
-# gcc-linaro-4.8-2014.01 build i686-precise-cbuild461-oort8-i686r1
+# gcc-linaro-4.8-2014.01 build i686-precise-abe461-oort8-i686r1
# and the one before it:
-# gcc-linaro-4.8-2013.12 build i686-precise-cbuild461-oort2-i686r1
+# gcc-linaro-4.8-2013.12 build i686-precise-abe461-oort2-i686r1
# ------
testfile()
diff --git a/lib/gerrit.sh b/lib/gerrit.sh
index 410aaaa..8061ced 100644
--- a/lib/gerrit.sh
+++ b/lib/gerrit.sh
@@ -25,7 +25,7 @@
# ssh -p 29418 robert.savoye@git.linaro.org gerrit version
# this uses the git commit SHA-1
# ssh -p 29418 robert.savoye@git.linaro.org gerrit review --code-review 0 -m "foo" a87c53e83236364fe9bc7d5ffdbf3c307c64707d
- # ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/cbuild2 --code-review 0 -m "foobar" a87c53e83236364fe9bc7d5ffdbf3c307c64707d
+ # ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/abe --code-review 0 -m "foobar" a87c53e83236364fe9bc7d5ffdbf3c307c64707d
# ssh -p 29418 robert.savoye@git.linaro.org gerrit query --current-patch-set gcc status:open limit:1 --format JSON
# The number used for code reviews looks like this, it's passed as a string to
@@ -37,7 +37,7 @@
# +2 Looks good to me, approved
-# ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/cbuild2 --code-review "+2" -m "foobar" 55957eaff3d80d854062544dea6fc0eedcbf9247 --submit
+# ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/abe --code-review "+2" -m "foobar" 55957eaff3d80d854062544dea6fc0eedcbf9247 --submit
# local revision="@`cd ${srcdir} && git log --oneline | head -1 | cut -d ' ' -f 1`"
@@ -215,7 +215,7 @@ Your patch is being reviewed. The build step has completed with a status of: ${s
EOF
-#http://cbuild.validation.linaro.org/logs/gcc-linaro-5.0.0/
+#http://abe.validation.linaro.org/logs/gcc-linaro-5.0.0/
add_gerrit_comment ${revision} ${msgfile} ${code}
if test $? -gt 0; then
diff --git a/lib/git-parser.sh b/lib/git-parser.sh
index 5474af6..07ee400 100644
--- a/lib/git-parser.sh
+++ b/lib/git-parser.sh
@@ -64,7 +64,7 @@
# The revision designation that follows the repository, e.g.,
# binutils.git@12345
#
-# Note: cbuild allows <repo>.git/branch@revision even though
+# Note: abe allows <repo>.git/branch@revision even though
# when a revision is present, the 'branch' is only used
# in path names, since a revision implies a branch already.
#
diff --git a/lib/globals.sh b/lib/globals.sh
index d50bdb6..4b156db 100644
--- a/lib/globals.sh
+++ b/lib/globals.sh
@@ -115,7 +115,7 @@ jenkins_job_url=""
# source a user specific config file for commonly used configure options.
# These overide any of the above values.
-if test -e ~/.cbuildrc; then
- . ~/.cbuildrc
+if test -e ~/.aberc; then
+ . ~/.aberc
fi
diff --git a/lib/make.sh b/lib/make.sh
index 4dc16dc..69ffc14 100755
--- a/lib/make.sh
+++ b/lib/make.sh
@@ -107,7 +107,7 @@ build_all()
local sysroot="`${target}-gcc -print-sysroot`"
if test ! -d ${sysroot}; then
dryrun "mkdir -p /opt/linaro"
- dryrun "ln -sfnT ${cbuild_top}/sysroots/${target} ${sysroot}"
+ dryrun "ln -sfnT ${abe_top}/sysroots/${target} ${sysroot}"
fi
fi
;;
diff --git a/lib/merge.sh b/lib/merge.sh
index 83fadc9..f57625c 100644
--- a/lib/merge.sh
+++ b/lib/merge.sh
@@ -85,7 +85,7 @@ merge_branch()
month="`date +%m`"
day="`date +%d`"
- # If no email address is in ~/.cbuildrc, create one
+ # If no email address is in ~/.aberc, create one
if test x"${email}" = x; then
email="${LOGNAME}@`hostname`"
fi
diff --git a/lib/release.sh b/lib/release.sh
index 7c23626..8355321 100755
--- a/lib/release.sh
+++ b/lib/release.sh
@@ -58,7 +58,7 @@ sign_tarball()
{
trace "$*"
-# ssh -t cbuild@toolchain64 gpg --no-use-agent -q --yes --passphrase-file /home/cbuild/.config/cbuild/password --armor --sign --detach-sig --default-key cbuild "/home/cbuild/var/snapshots/gcc-linaro-${release}.tar.xz" scp cbuild@toolchain64:/home/cbuild/var/snapshots/gcc-linaro-${release}.tar.xz.asc $REL_DIR
+# ssh -t abe@toolchain64 gpg --no-use-agent -q --yes --passphrase-file /home/abe/.config/abe/password --armor --sign --detach-sig --default-key abe "/home/abe/var/snapshots/gcc-linaro-${release}.tar.xz" scp abe@toolchain64:/home/abe/var/snapshots/gcc-linaro-${release}.tar.xz.asc $REL_DIR
return 0
}
@@ -116,7 +116,7 @@ release_binutils_src()
# From: https://wiki.linaro.org/WorkingGroups/ToolChain/GCC/ReleaseProcess
# The output file name looks like this: gcc-linaro-4.8-2013.11.tar.xz.
-# The date is set by the --release option to Cbuildv2. This function is
+# The date is set by the --release option to Abe. This function is
# only called with --tarsrc or --tarball.
release_gcc_src()
{
diff --git a/lib/stamp.sh b/lib/stamp.sh
index 054ddbb..af71648 100644
--- a/lib/stamp.sh
+++ b/lib/stamp.sh
@@ -100,7 +100,7 @@ create_stamp()
# you should not proceed with processing.
#
# 255 - There is an error condition during stamp generation. This is
-# a bug in cbuild2 or the filesystem.
+# a bug in abe or the filesystem.
#
check_stamp()
{
diff --git a/runbenchmark.sh b/runbenchmark.sh
index c1ef8c2..228bee0 100755
--- a/runbenchmark.sh
+++ b/runbenchmark.sh
@@ -225,13 +225,13 @@ fi
$extract || $clean || $build || $run || { extract=true;clean=true;build=true;run=true; }
-#Cribbed from cbuild2.sh
+#Cribbed from abe.sh
#TODO: Push this change back to last merge? Not really needed if I submit generated patches.
# But may still be worth it for my sanity.
make_docs=no
install=no
-#TODO How does primary cbuild2 do this?
+#TODO How does primary abe do this?
dump_host_info > host.txt
#fetch md5sums
diff --git a/scripts/Backport.job b/scripts/Backport.job
index 645ff24..a1c7601 100755
--- a/scripts/Backport.job
+++ b/scripts/Backport.job
@@ -1,6 +1,6 @@
#!/bin/bash
-cbuild_dir="${WORKSPACE}/cbuildv2"
+abe_dir="${WORKSPACE}/abe"
user_snapshots="${WORKSPACE}/snapshots"
shared="/home/buildslave/workspace/shared/"
snapshots_ref="${shared}/snapshots"
@@ -17,11 +17,11 @@ rm -fr ${WORKSPACE}
mkdir -p ${WORKSPACE}/_build
cd ${WORKSPACE}/_build
-$CONFIG_SHELL ${cbuild_dir}/configure --with-local-snapshots=${user_snapshots} --with-git-reference-dir=${snapshots_ref} --with-fileserver=148.251.136.42
+$CONFIG_SHELL ${abe_dir}/configure --with-local-snapshots=${user_snapshots} --with-git-reference-dir=${snapshots_ref} --with-fileserver=148.251.136.42
-$CONFIG_SHELL -x ${cbuild_dir}/test-backport.sh --fileserver=148.251.136.42 --target ${target} ${gcc_branch}
+$CONFIG_SHELL -x ${abe_dir}/test-backport.sh --fileserver=148.251.136.42 --target ${target} ${gcc_branch}
-# force a failure of cbuild2 has build problems.
+# force a failure of abe has build problems.
if test $? -gt 0; then
exit 1
fi
diff --git a/scripts/BuildFarm.job b/scripts/BuildFarm.job
index 95d103f..bf5a502 100755
--- a/scripts/BuildFarm.job
+++ b/scripts/BuildFarm.job
@@ -11,7 +11,7 @@ export runtests=true
export CONFIG_SHELL="/bin/bash"
shared="/home/buildslave/workspace/shared/"
-cbuild_dir="${WORKSPACE}/cbuildv2"
+abe_dir="${WORKSPACE}/abe"
user_snapshots="${WORKSPACE}/snapshots"
snapshots_ref="${shared}/snapshots"
@@ -19,10 +19,10 @@ rm -fr ${WORKSPACE}/_build
mkdir -p ${WORKSPACE}/_build
cd ${WORKSPACE}/_build
-$CONFIG_SHELL ${cbuild_dir}/configure --disable update --with-local-snapshots=${user_snapshots} --with-git-reference-dir=${shared}/snapshots
-$CONFIG_SHELL -x ${cbuild_dir}/jenkins.sh ${release}
+$CONFIG_SHELL ${abe_dir}/configure --disable update --with-local-snapshots=${user_snapshots} --with-git-reference-dir=${shared}/snapshots
+$CONFIG_SHELL -x ${abe_dir}/jenkins.sh ${release}
-# force a failure of cbuild2 has build problems.
+# force a failure of abe has build problems.
if test $? -gt 0; then
exit 1
fi
diff --git a/scripts/MakeRelease.job b/scripts/MakeRelease.job
index 915c42b..0e8b5d1 100755
--- a/scripts/MakeRelease.job
+++ b/scripts/MakeRelease.job
@@ -31,7 +31,7 @@ if test x"${target}" != x"native" -a x"${target}" != x; then
fi
shared="/home/buildslave/workspace/shared/"
-cbuild_dir="${user_workspace}/cbuildv2"
+abe_dir="${user_workspace}/abe"
user_snapshots="${user_workspace}/snapshots"
if test -e ${user_workspace}; then
@@ -54,7 +54,7 @@ fi
cd ${user_workspace}/_build
if ! test -e host.conf; then
- $CONFIG_SHELL ${cbuild_dir}/configure --with-local-snapshots=${user_snapshots} \
+ $CONFIG_SHELL ${abe_dir}/configure --with-local-snapshots=${user_snapshots} \
--with-git-reference-dir=${shared}/snapshots --with-fileserver=${fileserver}
fi
@@ -68,7 +68,7 @@ fi
# Build a toolchain, run the tests, and the create a source release as a tarball
if test x"${tarsrc}" = x"yes"; then
- $CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --disable update --release ${release} \
+ $CONFIG_SHELL ${abe_dir}/abe.sh --disable update --release ${release} \
--tarsrc ${check} gcc=${gcc_source} ${platform} -build all
fi
@@ -76,15 +76,15 @@ fi
if test x"${tarbin}" = x"yes"; then
# Canadian cross builds require a Linux hosted crfoss compiler first
if test x"${canadian}" = x"true"; then
- $CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --disable update --release ${release} ${check} gcc=${gcc_source} ${platform} --build all
+ $CONFIG_SHELL ${abe_dir}/abe.sh --disable update --release ${release} ${check} gcc=${gcc_source} ${platform} --build all
host="--host i686-w64-mingw32"
else
host=""
fi
- $CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --disable update --release ${release} --tarbin ${check} gcc=${gcc_source} ${platform} ${host} --build all
+ $CONFIG_SHELL ${abe_dir}/abe.sh --disable update --release ${release} --tarbin ${check} gcc=${gcc_source} ${platform} ${host} --build all
fi
-# force a failure if cbuild2 has build problems.
+# force a failure if abe has build problems.
if test $? -gt 0; then
exit 1
fi
@@ -95,8 +95,8 @@ if test x"${nocheck}" = xyes; then
fi
# Copy the source build test results and tarballs to the fileserver
-bases="/work/cbuildv2/baselines/${release}/${target}"
-snaps="/home/cbuild/var/snapshots/"
+bases="/work/abe/baselines/${release}/${target}"
+snaps="/home/abe/var/snapshots/"
if test x"${tarsrc}" = x"yes"; then
manifest="`find ${user_workspace} -name manifest.txt`"
scp ${manifest} ${fileserver}:${bases}/
@@ -144,7 +144,7 @@ if test x"${tarbin}" = xyes; then
fi
# Diff the two directories
- scp ${cbuild_dir}/tcwgweb.sh ${fileserver}:/tmp/tcwgweb$$.sh
+ scp ${abe_dir}/tcwgweb.sh ${fileserver}:/tmp/tcwgweb$$.sh
out="`ssh ${fileserver} "if test -e ${bases}; then echo YES; else echo NO; fi"`"
if test x"${out}" = x"YES"; then
out="`ssh ${fileserver} /tmp/tcwgweb$$.sh --email --tdir ${bases} ${binaries}; fi`"
diff --git a/tcwgweb.sh b/tcwgweb.sh
index 41fa19c..6f4eca3 100755
--- a/tcwgweb.sh
+++ b/tcwgweb.sh
@@ -22,9 +22,9 @@ if test -e "${PWD}/host.conf"; then
fi
# load commonly used functions
-cbuild="`which $0`"
-topdir="${cbuild_path}"
-cbuild2="`basename $0`"
+abe="`which $0`"
+topdir="${abe_path}"
+abe="`basename $0`"
. "${topdir}/lib/common.sh" || exit 1
@@ -86,7 +86,7 @@ diffbaseline ()
{
source $1/manifest.txt
- local baselines="/work/cbuildv2/baselines"
+ local baselines="/work/abe/baselines"
local tool="`echo $2 | cut -d '-' -f 1`"
local tool="`basename ${tool}`"
local version="`echo $2 | grep -o "[0-9]\.[0-9]*" | head -1`"
@@ -258,9 +258,9 @@ diffall ()
# This produces the test file, who's header needs to look like this:
#
# Difference in testsuite results between:
-# gcc-linaro-4.8-2014.01 build i686-precise-cbuild461-oort8-i686r1
+# gcc-linaro-4.8-2014.01 build i686-precise-abe461-oort8-i686r1
# and the one before it:
-# gcc-linaro-4.8-2013.12 build i686-precise-cbuild461-oort2-i686r1
+# gcc-linaro-4.8-2013.12 build i686-precise-abe461-oort2-i686r1
# ------
testfile()
diff --git a/testsuite/gerrit-tests.sh b/testsuite/gerrit-tests.sh
index c860e31..8df440a 100755
--- a/testsuite/gerrit-tests.sh
+++ b/testsuite/gerrit-tests.sh
@@ -7,7 +7,7 @@ cat <<EOF > ${review}
[gerrit]
host=review.linaro.org
port=29418
- project=toolchain/cbuild2
+ project=toolchain/abe
[gitreview]
username=buildslave
@@ -32,7 +32,7 @@ else
fi
out="`extract_gerrit_project ${srcdir}`"
-if test x"${out}" = x"toolchain/cbuild2"; then
+if test x"${out}" = x"toolchain/abe"; then
pass extract_gerrit_project""
else
${fail_state} "extract_gerrit_project"
diff --git a/testsuite/git-parser-tests.sh b/testsuite/git-parser-tests.sh
index 70d5f63..b72bbe5 100644
--- a/testsuite/git-parser-tests.sh
+++ b/testsuite/git-parser-tests.sh
@@ -1000,7 +1000,7 @@ match='linux'
test_parser tool "${in}" "${match}" "${errmatch}"
errmatch=0
-in="http://cbuild.validation.linaro.org/snapshots/gdb-7.6~20121001+git3e2e76a.tar"
+in="http://abe.validation.linaro.org/snapshots/gdb-7.6~20121001+git3e2e76a.tar"
match='gdb'
test_parser repo "${in}" "${match}" "${errmatch}"
diff --git a/testsuite/normalize-tests.sh b/testsuite/normalize-tests.sh
index e15fba1..37df311 100644
--- a/testsuite/normalize-tests.sh
+++ b/testsuite/normalize-tests.sh
@@ -81,7 +81,7 @@ else
fixme "${in} returned ${out}"
fi
-in="http://cbuild.validation.linaro.org/snapshots/gcc-linaro-4.8-2013.06-1.tar.xz"
+in="http://abe.validation.linaro.org/snapshots/gcc-linaro-4.8-2013.06-1.tar.xz"
out="`normalize_path ${in}`"
if test x"${out}" = x"gcc-linaro-4.8-2013.06-1"; then
pass "normalize_path: tarball compressed"
diff --git a/testsuite/test_sources.conf b/testsuite/test_sources.conf
index 1115185..7bd50c1 100644
--- a/testsuite/test_sources.conf
+++ b/testsuite/test_sources.conf
@@ -14,7 +14,7 @@ gcc_tab.git http://staging.git.linaro.org/git/toolchain/gcc.git
binutils.git git://git.linaro.org/toolchain/binutils.git
libgloss.git git://git.linaro.org/toolchain/newlib.git
newlib.git git://git.linaro.org/toolchain/newlib.git
-cbuild2.git http://git@staging.git.linaro.org/git/toolchain/cbuild2.git
+abe.git http://git@staging.git.linaro.org/git/toolchain/abe.git
eglibc.git git://git.linaro.org/toolchain/eglibc.git
glibc.git git://git.linaro.org/toolchain/glibc.git
bitbake.git git://git.openembedded.org/bitbake
diff --git a/validate.sh b/validate.sh
index dafc054..909eed4 100755
--- a/validate.sh
+++ b/validate.sh
@@ -20,7 +20,7 @@
if test -e "${PWD}/host.conf"; then
. "${PWD}/host.conf"
else
- echo "Error: this script needs to be run from a configured Cbuild2 tree!" 1>&2
+ echo "Error: this script needs to be run from a configured Abe tree!" 1>&2
fi
if test $# -lt 4; then
@@ -40,9 +40,9 @@ target=$1
shift
# load commonly used functions
-cbuild="`which $0`"
-topdir="${cbuild_path}"
-cbuild2="`basename $0`"
+abe="`which $0`"
+topdir="${abe_path}"
+abe="`basename $0`"
. "${topdir}/lib/diff.sh" || exit 1
@@ -51,7 +51,7 @@ declare -a revisions=($*)
# Get the path for the other scripts.
fullpath="`which $0`"
-cbuild2="`dirname ${fullpath}`/cbuild2.sh"
+abe="`dirname ${fullpath}`/abe.sh"
tcwgweb="`dirname ${fullpath}`/tcwgweb.sh"
# We'll move all the results to subdirectories under here
@@ -63,16 +63,16 @@ i=0
while test $i -lt ${#revisions[@]}; do
stamps="`ls -C1 ${local_builds}/${build}/${target}/*-stage2-build.stamp`"
if test "`echo ${stamps} | grep -c ${revisions[$i]}`" -eq 0; then
- ${cbuild2} --target ${target} --check gcc=gcc.git@${revisions[$i]} --build all
+ ${abe} --target ${target} --check gcc=gcc.git@${revisions[$i]} --build all
fi
sums="`find ${local_builds}/${build}/${target} -name \*.sum`"
if test x"${sums}" != x; then
- mkdir -p ${resultsdir}/cbuild${revisions[$i]}/${build}-${target}
- cp ${sums} ${resultsdir}/cbuild${revisions[$i]}/${build}-${target}
+ mkdir -p ${resultsdir}/abe${revisions[$i]}/${build}-${target}
+ cp ${sums} ${resultsdir}/abe${revisions[$i]}/${build}-${target}
# We don't need these files leftover from the DejaGnu testsuite
# itself.
- xz -f ${resultsdir}/cbuild${revisions[$i]}/${build}-${target}/*.sum
- rm ${resultsdir}/cbuild${revisions[$i]}/${build}-${target}/{x,xXx,testrun}.sum
+ xz -f ${resultsdir}/abe${revisions[$i]}/${build}-${target}/*.sum
+ rm ${resultsdir}/abe${revisions[$i]}/${build}-${target}/{x,xXx,testrun}.sum
fi
i=`expr $i + 1`
done
@@ -81,13 +81,13 @@ done
# is a series, do them all in the order they were specified on the
# command line.
if test ${#revisions[@]} -eq 2; then
- difftwodirs ${resultsdir}/cbuild${revisions[0]} ${resultsdir}/cbuild${revisions[1]}
+ difftwodirs ${resultsdir}/abe${revisions[0]} ${resultsdir}/abe${revisions[1]}
else
j=0
while test $j -lt ${#revisions[@]}; do
- first=cbuild${revisions[$j]}/${build}-${target}
+ first=abe${revisions[$j]}/${build}-${target}
j=`expr $j + 1`
- second=cbuild${revisions[$j]}/${build}-${target}
+ second=abe${revisions[$j]}/${build}-${target}
if test x"${second}" = x; then
break
else
diff --git a/jenkins.sh b/jenkins.sh
index 57cc203..14c37e5 100755
--- a/jenkins.sh
+++ b/jenkins.sh
@@ -21,7 +21,7 @@ usage()
{
# Format this section with 75 columns.
cat << EOF
- jenkins.sh [--help] [-s snapshot dir] [g git reference dir] [cbuildv2 path] [w workspace]
+ jenkins.sh [--help] [-s snapshot dir] [g git reference dir] [abe path] [w workspace]
EOF
return 0
}
@@ -54,16 +54,16 @@ user_snapshots="${user_workspace}/snapshots"
# The release version string, usually a date
releasestr=
# This is a string of optional extra arguments to pass to cbuild at runtime
user_options=""
-OPTS="`getopt -o s:g:c:w:o:f:t:h -l snapshots:gitrepo:cbuild:workspace:options:fileserver:target:help -- "$@"`"
+OPTS="`getopt -o s:g:c:w:o:f:t:h -l snapshots:gitrepo:abe:workspace:options:fileserver:target:help -- "$@"`"
while test $# -gt 0; do
echo 1 = "$1"
case $1 in
-s|--snapshots) user_snapshots=$2 ;;
-g|--gitrepo) user_git_repo=$2 ;;
- -c|--cbuild) cbuild_dir=$2 ;;
+ -c|--abe) abe_dir=$2 ;;
-t|--target) target=$2 ;;
-w|--workspace) user_workspace=$2 ;;
-o|--options) user_options=$2 ;;
@@ -161,7 +161,7 @@ fi
# Use the newly created build directory
pushd ${user_workspace}/_build
# Configure Cbuildv2 itself. Force the use of bash instead of the Ubuntu
# default of dash as some configure scripts go into an infinite loop with
# dash. Not good...
export CONFIG_SHELL="/bin/bash"
@@ -169,18 +169,18 @@ if test x"${debug}" = x"true"; then
export CONFIG_SHELL="/bin/bash -x"
fi
-if test x"${cbuild_dir}" = x; then
- cbuild_dir=${topdir}
+if test x"${abe_dir}" = x; then
+ abe_dir=${topdir}
fi
-$CONFIG_SHELL ${cbuild_dir}/configure --with-local-snapshots=${user_snapshots} --with-git-reference-dir=${shared}/snapshots --with-fileserver=${fileserver}
+$CONFIG_SHELL ${abe_dir}/configure --with-local-snapshots=${user_snapshots} --with-git-reference-dir=${shared}/snapshots --with-fileserver=${fileserver}
# load commonly used varibles set by configure
if test -e "${PWD}/host.conf"; then
. "${PWD}/host.conf"
fi
# This is the top level directory for the cbuild2 sources.
#cbuild_dir="${cbuild_path}"
# Delete the previous test result files to avoid problems.
find ${user_workspace} -name \*.sum -exec rm {} \; 2>&1 > /dev/null
@@ -189,14 +189,14 @@ find ${user_workspace} -name \*.sum -exec rm {} \; 2>&1 > /dev/null
# that to compile the cross compiler to bootstrap. Since it's just
# used to build the cross compiler, we don't bother to run 'make check'.
if test x"${bootstrap}" = xtrue; then
- $CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --parallel ${change} --bootstrap --build all
+ $CONFIG_SHELL ${abe_dir}/abe.sh --parallel ${change} --bootstrap --build all
fi
# Now we build the cross compiler, for a native compiler this becomes
# the stage2 bootstrap build.
-$CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --parallel ${check} ${tars} ${releasestr} ${platform} ${change} --timeout 100 --build all
+$CONFIG_SHELL ${abe_dir}/abe.sh --parallel ${check} ${tars} ${releasestr} ${platform} ${change} --timeout 100 --build all
-# If cbuild2 returned an error, make jenkins see this as a build failure
+# If abe returned an error, make jenkins see this as a build failure
if test $? -gt 0; then
exit 1
fi
@@ -290,7 +290,7 @@ if test x"${runtests}" = xtrue; then
#if test x"${sums}" != x; then
# for i in ${sums}; do
# name="`basename $i`"
-# ${cbuild_dir}/sum2junit.sh $i $user_workspace/${name}.junit
+# ${abe_dir}/sum2junit.sh $i $user_workspace/${name}.junit
# cp $i ${user_workspace}/results/${dir}
# done
# junits="`find ${user_workspace} -name *.junit`"
@@ -309,13 +309,13 @@ sums="`find ${user_workspace} -name *.sum`"
# Canadian Crosses are a win32 hosted cross toolchain built on a Linux
# machine.
if test x"${canadian}" = x"true"; then
- $CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --nodepends --parallel ${change} ${platform} --build all
+ $CONFIG_SHELL ${abe_dir}/abe.sh --nodepends --parallel ${change} ${platform} --build all
distro="`lsb_release -sc`"
# Ubuntu Lucid uses an older version of Mingw32
if test x"${distro}" = x"lucid"; then
- $CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --nodepends --parallel ${change} ${tars} --host=i586-mingw32msvc ${platform} --build all
+ $CONFIG_SHELL ${abe_dir}/abe.sh --nodepends --parallel ${change} ${tars} --host=i586-mingw32msvc ${platform} --build all
else
- $CONFIG_SHELL ${cbuild_dir}/cbuild2.sh --nodepends --parallel ${change} ${tars} --host=i686-w64-mingw32 ${platform} --build all
+ $CONFIG_SHELL ${abe_dir}/abe.sh --nodepends --parallel ${change} ${tars} --host=i686-w64-mingw32 ${platform} --build all
fi
fi
@@ -336,7 +336,7 @@ if test x"${sums}" != x -o x"${runtests}" != x"true"; then
logs="`find ${user_workspace} -name make\*.log`"
scp ${logs} ${fileserver}:${basedir}/${dir}/
ssh ${fileserver} xz ${basedir}/${dir}/\*.sum ${basedir}/${dir}/\*.log
- scp ${cbuild_dir}/tcwgweb.sh ${fileserver}:/tmp/tcwgweb$$.sh
+ scp ${abe_dir}/tcwgweb.sh ${fileserver}:/tmp/tcwgweb$$.sh
ssh ${fileserver} /tmp/tcwgweb$$.sh --email --base ${basedir}/${dir}
ssh ${fileserver} rm -f /tmp/tcwgweb$$.sh
@@ -345,7 +345,7 @@ if test x"${sums}" != x -o x"${runtests}" != x"true"; then
if test x"${tarsrc}" = xtrue -a x"${release}" != x; then
allfiles="`ls ${shared}/snapshots/*${release}*.xz`"
srcfiles="`echo ${allfiles} | egrep -v "arm|aarch"`"
- scp ${srcfiles} ${fileserver}:/home/cbuild/var/snapshots/
+ scp ${srcfiles} ${fileserver}:/home/abe/var/snapshots/
rm -f ${srcfiles}
fi
@@ -54,16 +54,16 @@ user_snapshots="${user_workspace}/snapshots"
# The release version string, usually a date
releasestr=
-# This is a string of optional extra arguments to pass to cbuild at runtime
+# This is a string of optional extra arguments to pass to abe at runtime
user_options=""
@@ -161,7 +161,7 @@ fi
# Use the newly created build directory
pushd ${user_workspace}/_build
-# Configure Cbuildv2 itself. Force the use of bash instead of the Ubuntu
+# Configure Abe itself. Force the use of bash instead of the Ubuntu
# default of dash as some configure scripts go into an infinite loop with
# dash. Not good...
@@ -169,18 +169,18 @@ if test x"${debug}" = x"true"; then
. "${PWD}/host.conf"
fi
-# This is the top level directory for the cbuild2 sources.
-#cbuild_dir="${cbuild_path}"
+# This is the top level directory for the abe sources.
+#abe_dir="${abe_path}"
# Delete the previous test result files to avoid problems.
find ${user_workspace} -name \*.sum -exec rm {} \; 2>&1 > /dev/null
diff --git a/lib/package.sh b/lib/package.sh
index df111b9..398ab8f 100644
--- a/lib/package.sh
+++ b/lib/package.sh
@@ -279,10 +279,10 @@ binary_sysroot()
local tag="sysroot-linaro-${clibrary}-gcc${version}-${release}-${target}"
fi
-# dryrun "cp -fr ${cbuild_top}/sysroots/${target} ${destdir}"
+# dryrun "cp -fr ${abe_top}/sysroots/${target} ${destdir}"
local destdir="/tmp/linaro.$$/${tag}"
dryrun "mkdir -p /tmp/linaro.$$"
- dryrun "ln -sfnT ${cbuild_top}/sysroots/${target} ${destdir}"
+ dryrun "ln -sfnT ${abe_top}/sysroots/${target} ${destdir}"
# Generate the install script
sysroot_install_script ${destdir}
@@ -347,7 +347,7 @@ manifest()
local srcdir="`get_srcdir ${binutils_version}`"
local binutils_revision=="`get_git_revision ${srcdir}`"
- local cbuild_revision="`get_git_revision ${cbuild_path}`"
+ local abe_revision="`get_git_revision ${abe_path}`"
rm -f ${outfile}
cat >> ${outfile} <<EOF
@@ -375,8 +375,8 @@ gdb_version=${gdb_version}
gdb_revsion=${gdb_revision}
linux_version=${linux_version}
-# Cbuild revision used
-cbuild_revision=${cbuild_revision}
+# Abe revision used
+abe_revision=${abe_revision}
EOF
@@ -513,7 +513,7 @@ binutils_src_tarball()
return 0
}
# This installs a binary tarball produced by cbuild2, and runs make check
test_binary_toolchain()
{
# Binaries get installed here if possible
@@ -513,7 +513,7 @@ binutils_src_tarball()
return 0
}
-# This installs a binary tarball produced by cbuild2, and runs make check
+# This installs a binary tarball produced by abe, and runs make check
test_binary_toolchain()
{
diff --git a/test-backport.sh b/test-backport.sh
index 4dadb36..b9d0f65 100755
--- a/test-backport.sh
+++ b/test-backport.sh
@@ -16,7 +16,7 @@
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
#
# To run, this script takes arguments in the same format as cbuild2.sh. The two
# arguments it needs is the target archicture to build, and the gcc backport
# branch name. Example:
# $PATH/test-backport.sh --target arm-linux-gnueabihf gcc.git~4.9-backport-209419
@@ -39,11 +39,11 @@ fi
if test -e "${PWD}/host.conf"; then
. "${PWD}/host.conf"
else
- echo "Error: this script needs to be run from a configured Cbuild2 tree!" 1>&2
+ echo "Error: this script needs to be run from a configured Abe tree!" 1>&2
fi
-cbuild="`which $0`"
-topdir="${cbuild_path}"
-cbuild2="`basename $0`"
+abe="`which $0`"
+topdir="${abe_path}"
+abe="`basename $0`"
repo="gcc.git"
fileserver=""
@@ -86,12 +86,12 @@ declare -a revisions=(`cd ${srcdir} && git log -n 2 | grep ^commit | cut -d ' '
# Force GCC to not build the docs
export BUILD_INFO=""
-resultsdir="/tmp/cbuild-${target}@"
+resultsdir="/tmp/abe-${target}@"
i=0
while test $i -lt ${#revisions[@]}; do
- bash -x ${topdir}/cbuild2.sh --disable update --check --target ${target} gcc=gcc.git@${revisions[$i]} --build all --disable make_docs
+ bash -x ${topdir}/abe.sh --disable update --check --target ${target} gcc=gcc.git@${revisions[$i]} --build all --disable make_docs
if test $? -gt 0; then
- echo "ERROR: Cbuild2 failed!"
+ echo "ERROR: Abe failed!"
exit 1
fi
sums="`find ${local_builds}/${build}/${target} -name \*.sum`"
@@ -16,7 +16,7 @@
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
#
-# To run, this script takes arguments in the same format as cbuild2.sh. The two
+# To run, this script takes arguments in the same format as abe.sh. The two
# arguments it needs is the target archicture to build, and the gcc backport
# branch name. Example:
diff --git a/test.sh b/test.sh
index e1d5f97..818a723 100755
--- a/test.sh
+++ b/test.sh
@@ -1,22 +1,22 @@
#!/bin/bash
-testcbuild2="`basename $0`"
+testabe="`basename $0`"
topdir=`dirname $0`
-cbuild_path=`readlink -f ${topdir}`
-export cbuild_path
+abe_path=`readlink -f ${topdir}`
+export abe_path
# Source common.sh for some common utilities.
-. ${cbuild_path}/lib/common.sh || exit 1
+. ${abe_path}/lib/common.sh || exit 1
# We use a tmp/ directory for the builddir in order that we don't pollute the
# srcdir or an existing builddir.
-tmpdir=`mktemp -d /tmp/cbuild2.$$.XXX`
+tmpdir=`mktemp -d /tmp/abe.$$.XXX`
if test "$?" -gt 0; then
error "mktemp of ${tmpdir} failed."
exit 1
fi
# Log files for cbuild test runs are dumped here.
testlogs=${tmpdir}/testlogs
mkdir -p ${testlogs}
if test "$?" -gt 0; then
@@ -29,14 +29,14 @@ runintmpdir=
# existing build dir, otherwise we're in the srcdir so we need to run
# configure in the tmpdir and run the tests from there.
if test ! -e "${PWD}/host.conf"; then
- (cd ${tmpdir} && ${cbuild_path}/configure --with-sources-conf=${cbuild_path}/testsuite/test_sources.conf)
+ (cd ${tmpdir} && ${abe_path}/configure --with-sources-conf=${abe_path}/testsuite/test_sources.conf)
runintmpdir=yes
else
# copy the md5sums file from the existing snapshots directory to the new local_snapshots directory.
# Override $local_snapshots so that the local_snapshots directory of an
# existing build is not moved or damaged. This affects all called
# instances of cbuild2.sh below.
export local_snapshots="${tmpdir}/snapshots"
out="`mkdir -p ${local_snapshots}`"
if test "$?" -gt 0; then
@@ -44,19 +44,19 @@ else
exit 1
fi
# Override the existing sources_conf setting in host.conf.
- export sources_conf=${cbuild_path}testsuite/test_sources.conf
+ export sources_conf=${abe_path}testsuite/test_sources.conf
fi
export wget_quiet=yes
usage()
{
- echo " ${testcbuild2} [--debug|-v]"
+ echo " ${testabe} [--debug|-v]"
echo " [--md5sums <path/to/alternative/snapshots/md5sums>]"
echo ""
- echo " ${testcbuild2} is the cbuild2 frontend command conformance test."
+ echo " ${testabe} is the abe frontend command conformance test."
echo ""
- echo " ${testcbuild2} should be run from the source directory."
+ echo " ${testabe} should be run from the source directory."
}
passes=0
@@ -157,7 +157,7 @@ test_failure()
local match=$2
local out=
- out="`(${runintmpdir:+cd ${tmpdir}} && ${cbuild_path}/cbuild2.sh ${cb_commands} 2>&1 | tee ${testlogs}/${testlineno}.log | grep "${match}" | sed -e 's:\(^ERROR\).*\('"${match}"'\).*:\1 \2:')`"
+ out="`(${runintmpdir:+cd ${tmpdir}} && ${abe_path}/abe.sh ${cb_commands} 2>&1 | tee ${testlogs}/${testlineno}.log | grep "${match}" | sed -e 's:\(^ERROR\).*\('"${match}"'\).*:\1 \2:')`"
cbtest ${testlineno} "${out}" "ERROR ${match}" "ERROR ${cb_commands}"
}
@@ -169,7 +169,7 @@ test_pass()
local out=
# Continue to search for error so we don't get false positives.
- out="`(${runintmpdir:+cd ${tmpdir}} && ${cbuild_path}/cbuild2.sh ${cb_commands} 2>&1 | tee ${testlogs}/${testlineno}.log | grep "${match}" | sed -e 's:\(^ERROR\).*\('"${match}"'\).*:\1 \2:')`"
+ out="`(${runintmpdir:+cd ${tmpdir}} && ${abe_path}/abe.sh ${cb_commands} 2>&1 | tee ${testlogs}/${testlineno}.log | grep "${match}" | sed -e 's:\(^ERROR\).*\('"${match}"'\).*:\1 \2:')`"
cbtest ${testlineno} "${out}" "${match}" "VALID ${cb_commands}"
}
@@ -607,7 +607,7 @@ test_pass "${cb_commands}" "${match}"
# be grepped in 'match'... yet.
cb_commands="--dryrun --build gcc.git --stage 2"
testlineno="`expr $LINENO + 1`"
-out="`(${runintmpdir:+cd ${tmpdir}} && ${cbuild_path}/cbuild2.sh ${cb_commands} 2>&1 | tee ${testlogs}/${testlineno}.log | grep -c " build.*gcc.*stage2")`"
+out="`(${runintmpdir:+cd ${tmpdir}} && ${abe_path}/abe.sh ${cb_commands} 2>&1 | tee ${testlogs}/${testlineno}.log | grep -c " build.*gcc.*stage2")`"
if test ${out} -gt 0; then
pass ${testlineno} "VALID: --dryrun --build gcc.git --stage 2"
else
@@ -630,7 +630,7 @@ if test x"${tmpdir}" = x"/tmp"; then
echo "\n${local_snapshots} doesn't conform to /tmp/<tmpdir>/snapshots. Not safe to remove."
elif test -d "${tmpdir}/snapshots" -a ${failures} -lt 1; then
echo ""
- echo "${testcbuild2} finished with no unexpected failures. Removing ${tmpdir}"
+ echo "${testabe} finished with no unexpected failures. Removing ${tmpdir}"
rm -rf ${tmpdir}
fi
@@ -1,22 +1,22 @@
exit 1
fi
-# Log files for cbuild test runs are dumped here.
+# Log files for abe test runs are dumped here.
testlogs=${tmpdir}/testlogs
mkdir -p ${testlogs}
@@ -29,14 +29,14 @@ runintmpdir=
# Override $local_snapshots so that the local_snapshots directory of an
# existing build is not moved or damaged. This affects all called
- # instances of cbuild2.sh below.
+ # instances of abe.sh below.
export local_snapshots="${tmpdir}/snapshots"
out="`mkdir -p ${local_snapshots}`"
diff --git a/testsuite/srcdir-tests.sh b/testsuite/srcdir-tests.sh
index 53c1e34..3a9c09a 100644
--- a/testsuite/srcdir-tests.sh
+++ b/testsuite/srcdir-tests.sh
@@ -100,11 +100,11 @@ fi
echo "============= additional get_srcdir () tests ================"
# Some of these are redundant with those in srcdir_tests but since
# already have cbuild2.git checked out we might as well test them here.
testing="get_srcdir: <repo>.git"
-in="cbuild2.git"
+in="abe.git"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git"; then
+if test x"${out}" = x"${local_snapshots}/abe.git"; then
pass "${testing}"
else
fail "${testing}"
@@ -112,9 +112,9 @@ else
fi
testing="get_srcdir: <repo>.git@<revision>"
-in="cbuild2.git@12345"
+in="abe.git@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe.git@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -122,9 +122,9 @@ else
fi
testing="get_srcdir: <repo>.git/<branch>"
-in="cbuild2.git/branch"
+in="abe.git/branch"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git~branch"; then
+if test x"${out}" = x"${local_snapshots}/abe.git~branch"; then
pass "${testing}"
else
fail "${testing}"
@@ -132,9 +132,9 @@ else
fi
testing="get_srcdir: <repo>.git/<branch>@<revision>"
-in="cbuild2.git/branch@12345"
+in="abe.git/branch@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git~branch@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe.git~branch@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -142,9 +142,9 @@ else
fi
testing="get_srcdir: <repo>.git~<branch>@<revision>"
-in="cbuild2.git~branch@12345"
+in="abe.git~branch@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git~branch@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe.git~branch@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -152,9 +152,9 @@ else
fi
testing="get_srcdir: <repo>.git/<multi/part/branch>@<revision>"
-in="cbuild2.git/multi/part/branch@12345"
+in="abe.git/multi/part/branch@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git~multi-part-branch@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe.git~multi-part-branch@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -162,9 +162,9 @@ else
fi
testing="get_srcdir: <repo>.git~<multi/part/branch>@<revision>"
-in="cbuild2.git~multi/part/branch@12345"
+in="abe.git~multi/part/branch@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git~multi-part-branch@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe.git~multi-part-branch@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -174,7 +174,7 @@ fi
#
testing="get_srcdir: invalid identifier shouldn't return anything."
-in="cbuild2~multi/part/branch@12345"
+in="abe~multi/part/branch@12345"
out="`get_srcdir $in 2>/dev/null`"
if test x"${out}" = x""; then
pass "${testing}"
@@ -184,9 +184,9 @@ else
fi
testing="get_srcdir: <repo>~<multi/part/branch>@<revision>"
-in="git://git.linaro.org/people/rsavoye/cbuild2~multi/part/branch@12345"
+in="git://git.linaro.org/people/rsavoye/abe~multi/part/branch@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2~multi-part-branch@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe~multi-part-branch@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -194,9 +194,9 @@ else
fi
testing="get_srcdir: <repo>.git~<multi/part/branch>@<revision>"
-in="cbuild2.git~multi/part/branch@12345"
+in="abe.git~multi/part/branch@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git~multi-part-branch@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe.git~multi-part-branch@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -204,9 +204,9 @@ else
fi
testing="get_srcdir: http://<user>@<url>/<repo>.git"
-in="http://git@staging.git.linaro.org/git/toolchain/cbuild2.git"
+in="http://git@staging.git.linaro.org/git/toolchain/abe.git"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git"; then
+if test x"${out}" = x"${local_snapshots}/abe.git"; then
pass "${testing}"
else
fail "${testing}"
@@ -214,9 +214,9 @@ else
fi
testing="get_srcdir: http://<user>@<url>/<repo>.git@<revision>"
-in="http://git@staging.git.linaro.org/git/toolchain/cbuild2.git@12345"
+in="http://git@staging.git.linaro.org/git/toolchain/abe.git@12345"
out="`get_srcdir $in`"
-if test x"${out}" = x"${local_snapshots}/cbuild2.git@12345"; then
+if test x"${out}" = x"${local_snapshots}/abe.git@12345"; then
pass "${testing}"
else
fail "${testing}"
@@ -100,11 +100,11 @@ fi
echo "============= additional get_srcdir () tests ================"
# Some of these are redundant with those in srcdir_tests but since
-# already have cbuild2.git checked out we might as well test them here.
+# already have abe.git checked out we might as well test them here.
testing="get_srcdir: <repo>.git"
diff --git a/testsuite/test.sh b/testsuite/test.sh
index 6ea126c..966323d 100755
--- a/testsuite/test.sh
+++ b/testsuite/test.sh
@@ -2,7 +2,7 @@
# common.sh loads all the files of library functions.
if test x"`echo \`dirname "$0"\` | sed 's:^\./::'`" != x"testsuite"; then
- echo "WARNING: Should be run from top cbuild2 dir" > /dev/stderr
+ echo "WARNING: Should be run from top abe dir" > /dev/stderr
topdir="`readlink -e \`dirname $0\`/..`"
else
topdir=$PWD
@@ -17,7 +17,7 @@ else
. "${topdir}/lib/common.sh" || exit 1
warning "no host.conf file! Synthesizing a framework for testing."
- remote_snapshots=http://cbuild.validation.linaro.org/snapshots
+ remote_snapshots=http://abe.validation.linaro.org/snapshots
wget_bin=/usr/bin/wget
sources_conf=${topdir}/testsuite/test_sources.conf
fi
@@ -28,13 +28,13 @@ wget_quiet=yes
# We always override $local_snapshots so that we don't damage or move the
# local_snapshots directory of an existing build.
-local_cbuild_tmp="`mktemp -d /tmp/cbuild2.$$.XXX`"
-local_snapshots="${local_cbuild_tmp}/snapshots"
+local_abe_tmp="`mktemp -d /tmp/abe.$$.XXX`"
+local_snapshots="${local_abe_tmp}/snapshots"
# If this isn't being run in an existing build dir, create one in our
# temp directory.
if test ! -d "${local_builds}"; then
- local_builds="${local_cbuild_tmp}/builds"
+ local_builds="${local_abe_tmp}/builds"
out="`mkdir -p ${local_builds}`"
if test "$?" -gt 1; then
error "Couldn't create local_builds dir ${local_builds}"
@@ -57,7 +57,7 @@ out="`mkdir -p ${local_snapshots}`"
# Since we're testing, we don't load the host.conf file, instead
# we create false values that stay consistent.
-cbuild_top=/build/cbuild2/test
+abe_top=/build/abe/test
hostname=test.foobar.org
target=x86_64-linux-gnu
@@ -135,7 +135,7 @@ totals()
echo "============= get_toolname() tests ================"
testing="get_toolname: uncompressed tarball"
-in="http://cbuild.validation.linaro.org/snapshots/gdb-7.6~20121001+git3e2e76a.tar"
+in="http://abe.validation.linaro.org/snapshots/gdb-7.6~20121001+git3e2e76a.tar"
out="`get_toolname ${in}`"
if test ${out} = "gdb"; then
pass "${testing}"
@@ -146,7 +146,7 @@ fi
# ----------------------------------------------------------------------------------
testing="get_toolname: compressed tarball"
-in="http://cbuild.validation.linaro.org/snapshots/gcc-linaro-4.8-2013.06-1.tar.xz"
+in="http://abe.validation.linaro.org/snapshots/gcc-linaro-4.8-2013.06-1.tar.xz"
out="`get_toolname ${in}`"
if test ${out} = "gcc"; then
pass "${testing}"
@@ -1249,8 +1249,8 @@ if test x"${out}" = x"gcc-linaro-4.8-${date}"; then
xpass "${testing}"
else
# This fails because the tarball name fails to extract the version. This
# behavious isn't used by Cbuildv, it was an early feature to have some
# compatability with cbuildv1, which used tarballs. Cbuildv2 produces the
# tarballs, it doesn't need to import them anymore.
xfail "${testing}"
fixme "create_release_tag returned ${out}"
@@ -1320,7 +1320,7 @@ test_checkout ()
testing="checkout: http://git@<url>/<repo>.git"
if test ! -e "${PWD}/host.conf"; then
- package="cbuild2.git"
+ package="abe.git"
branch=''
revision=''
should="pass"
@@ -1331,7 +1331,7 @@ fi
testing="checkout: http://git@<url>/<repo>.git/<branch>"
if test ! -e "${PWD}/host.conf"; then
- package="cbuild2.git"
+ package="abe.git"
branch="gerrit"
revision=''
should="pass"
@@ -1342,7 +1342,7 @@ fi
testing="checkout: http://git@<url>/<repo>.git@<revision>"
if test ! -e "${PWD}/host.conf"; then
- package="cbuild2.git"
+ package="abe.git"
branch=''
revision="9bcced554dfc"
should="pass"
@@ -1353,7 +1353,7 @@ fi
testing="checkout: http://git@<url>/<repo>.git/unusedbranchnanme@<revision>"
if test ! -e "${PWD}/host.conf"; then
- package="cbuild2.git"
+ package="abe.git"
branch="unusedbranchname"
revision="9bcced554dfc"
should="pass"
@@ -1364,7 +1364,7 @@ fi
testing="checkout: http://git@<url>/<repo>.git/<nonexistentbranch> should fail."
if test ! -e "${PWD}/host.conf"; then
- package="cbuild2.git"
+ package="abe.git"
branch="nonexistentbranch"
revision=''
should="fail"
@@ -1375,7 +1375,7 @@ fi
testing="checkout: http://git@<url>/<repo>.git@<nonexistentrevision> should fail."
if test ! -e "${PWD}/host.conf"; then
- package="cbuild2.git"
+ package="abe.git"
branch=''
revision="123456bogusbranch"
should="fail"
@@ -1249,8 +1249,8 @@ if test x"${out}" = x"gcc-linaro-4.8-${date}"; then
else
# This fails because the tarball name fails to extract the version. This
- # behavious isn't used by Cbuildv, it was an early feature to have some
- # compatability with cbuildv1, which used tarballs. Cbuildv2 produces the
+ # behavious isn't used by Abe, it was an early feature to have some
+ # compatability with abev1, which used tarballs. Abe produces the
# tarballs, it doesn't need to import them anymore.
xfail "${testing}"